@@ -17,13 +17,13 @@ ajax '/ajax/control/admin/timedoutdevices/del' => require_role admin => sub {
     send_error('Missing backend', 400) unless param('backend');
     send_error('Missing device',  400) unless param('device');
 
-    schema('netdisco')->resultset('DeviceSkip')->find_or_create({
+    schema(vars->{'tenant'})->resultset('DeviceSkip')->find_or_create({
       backend => param('backend'), device => param('device'),
     },{ key => 'device_skip_pkey' })->update({ deferrals => 0 });
 };
 
 ajax '/ajax/content/admin/timedoutdevices' => require_role admin => sub {
-    my @set = schema('netdisco')->resultset('DeviceSkip')->search({
+    my @set = schema(vars->{'tenant'})->resultset('DeviceSkip')->search({
       deferrals => { '>' => 0 }
     },{ rows => (setting('dns')->{max_outstanding} || 50), order_by =>
       [{ -desc => 'deferrals' }, { -asc => [qw/device backend/] }]
